@@ -75,14 +75,26 @@ write2_using_print <- function(object, file, ..., output_format = NULL)
 #' @export
 write2.tableby <- write2_using_summary
 
+#' @rdname write2
+#' @export
+write2.summary.tableby <- write2_using_print
+
 #' @rdname write2
 #' @export
 write2.modelsum <- write2_using_summary
 
+#' @rdname write2
+#' @export
+write2.summary.modelsum <- write2_using_print
+
 #' @rdname write2
 #' @export
 write2.freqlist <- write2_using_summary
 
+#' @rdname write2
+#' @export
+write2.summary.freqlist <- write2_using_print
+
 #' @rdname write2
 #' @export
 write2.compare.data.frame <- write2_using_summary
